@@ -12,9 +12,9 @@ See :doc:`/tutorials/configuration` for an introduction to Manim's configuration
 import argparse
 import configparser
 import copy
+import errno
 import logging
 import os
-import errno
 import sys
 import typing
 from collections.abc import Mapping, MutableMapping
@@ -25,6 +25,7 @@ import numpy as np
 
 from .. import constants
 from ..utils.tex import TexTemplate, TexTemplateFromFile
+from ..utils.tex_templates import TexTemplateLibrary
 from .logger_utils import set_file_logger
 
 
@@ -115,13 +116,6 @@ def make_config_parser(custom_file: str = None) -> configparser.ConfigParser:
 
 
 def _determine_quality(args: argparse.Namespace) -> str:
-    old_qualities = {
-        "k": "fourk_quality",
-        "e": "high_quality",
-        "m": "medium_quality",
-        "l": "low_quality",
-    }
-
     for quality in constants.QUALITIES:
         if quality == constants.DEFAULT_QUALITY:
             # Skip so we prioritize anything that overwrites the default quality.
@@ -133,13 +127,6 @@ def _determine_quality(args: argparse.Namespace) -> str:
         ):
             return quality
 
-    for quality in old_qualities:
-        if getattr(args, quality, None):
-            logging.getLogger("manim").warning(
-                f"Option -{quality} is deprecated please use the --quality/-q flag."
-            )
-            return old_qualities[quality]
-
     return constants.DEFAULT_QUALITY
 
 
@@ -171,11 +158,11 @@ class ManimConfig(MutableMapping):
     Each config option allows for dict syntax and attribute syntax.  For
     example, the following two lines are equivalent,
 
-    .. code-block:: python
+    .. code-block:: pycon
 
-       >>> from manim import config, WHITE
-       >>> config.background_color = WHITE
-       >>> config['background_color'] = WHITE
+        >>> from manim import config, WHITE
+        >>> config.background_color = WHITE
+        >>> config["background_color"] = WHITE
 
     The former is preferred; the latter is provided mostly for backwards
     compatibility.
@@ -183,7 +170,7 @@ class ManimConfig(MutableMapping):
     The config options are designed to keep internal consistency.  For example,
     setting ``frame_y_radius`` will affect ``frame_height``:
 
-    .. code-block:: python
+    .. code-block:: pycon
 
         >>> config.frame_height
         8.0
@@ -238,9 +225,12 @@ class ManimConfig(MutableMapping):
     .. code-block:: python
 
         from manim import *
+
         config.background_color = RED
+
+
         class MyScene(Scene):
-            # ...
+            ...
 
     the background color will be set to RED, regardless of the contents of
     ``manim.cfg`` or the CLI arguments used when invoking manim.
@@ -254,6 +244,7 @@ class ManimConfig(MutableMapping):
         "custom_folders",
         "disable_caching",
         "ffmpeg_loglevel",
+        "format",
         "flush_cache",
         "frame_height",
         "frame_rate",
@@ -265,12 +256,13 @@ class ManimConfig(MutableMapping):
         "input_file",
         "media_width",
         "webgl_renderer_path",
-        "leave_progress_bars",
         "log_dir",
         "log_to_file",
         "max_files_cached",
         "media_dir",
         "movie_file_extension",
+        "notify_outdated_version",
+        "output_file",
         "partial_movie_dir",
         "pixel_height",
         "pixel_width",
@@ -283,14 +275,13 @@ class ManimConfig(MutableMapping):
         "save_pngs",
         "scene_names",
         "show_in_file_browser",
-        "sound",
         "tex_dir",
         "tex_template_file",
         "text_dir",
         "upto_animation_number",
+        "renderer",
         "use_opengl_renderer",
         "use_webgl_renderer",
-        "webgl_updater_fps",
         "verbosity",
         "video_dir",
         "write_all",
@@ -443,6 +434,12 @@ class ManimConfig(MutableMapping):
                 f"{key} must be a non-negative integer (use -1 for infinity)"
             )
 
+    def __repr__(self) -> str:
+        rep = ""
+        for k, v in sorted(self._d.items(), key=lambda x: x[0]):
+            rep += f"{k}: {v}, "
+        return rep
+
     # builders
     def digest_parser(self, parser: configparser.ConfigParser) -> "ManimConfig":
         """Process the config options present in a :class:`ConfigParser` object.
@@ -498,6 +495,7 @@ class ManimConfig(MutableMapping):
 
         # boolean keys
         for key in [
+            "notify_outdated_version",
             "write_to_movie",
             "save_last_frame",
             "write_all",
@@ -505,9 +503,6 @@ class ManimConfig(MutableMapping):
             "save_as_gif",
             "preview",
             "show_in_file_browser",
-            "progress_bar",
-            "sound",
-            "leave_progress_bars",
             "log_to_file",
             "disable_caching",
             "flush_cache",
@@ -521,12 +516,10 @@ class ManimConfig(MutableMapping):
         for key in [
             "from_animation_number",
             "upto_animation_number",
-            "frame_rate",
             "max_files_cached",
             # the next two must be set BEFORE digesting frame_width and frame_height
             "pixel_height",
             "pixel_width",
-            "webgl_updater_fps",
         ]:
             setattr(self, key, parser["CLI"].getint(key))
 
@@ -546,6 +539,7 @@ class ManimConfig(MutableMapping):
             "png_mode",
             "movie_file_extension",
             "background_color",
+            "renderer",
             "webgl_renderer_path",
         ]:
             setattr(self, key, parser["CLI"].get(key, fallback="", raw=True))
@@ -553,6 +547,7 @@ class ManimConfig(MutableMapping):
         # float keys
         for key in [
             "background_opacity",
+            "frame_rate",
             # the next two are floats but have their own logic, applied later
             # "frame_width",
             # "frame_height",
@@ -573,6 +568,10 @@ class ManimConfig(MutableMapping):
         if val:
             self.tex_template_file = val
 
+        val = parser["CLI"].get("progress_bar")
+        if val:
+            setattr(self, "progress_bar", val)
+
         val = parser["ffmpeg"].get("loglevel")
         if val:
             self.ffmpeg_loglevel = val
@@ -620,25 +619,25 @@ class ManimConfig(MutableMapping):
         self.output_file = args.output_file
 
         for key in [
+            "notify_outdated_version",
             "preview",
             "show_in_file_browser",
-            "sound",
-            "leave_progress_bars",
-            "progress_bar",
             "write_to_movie",
             "save_last_frame",
             "save_pngs",
             "save_as_gif",
             "write_all",
             "disable_caching",
+            "format",
             "flush_cache",
+            "progress_bar",
             "transparent",
             "scene_names",
             "verbosity",
+            "renderer",
             "background_color",
             "use_opengl_renderer",
             "use_webgl_renderer",
-            "webgl_updater_fps",
         ]:
             if hasattr(args, key):
                 attr = getattr(args, key)
@@ -664,34 +663,32 @@ class ManimConfig(MutableMapping):
                 if attr is not None:
                     self[key] = attr
 
-        # The -s (--save_last_frame) flag invalidates -w (--write_to_movie).
         if self["save_last_frame"]:
             self["write_to_movie"] = False
 
         # Handle the -n flag.
         nflag = args.from_animation_number
-        if nflag is not None:
-            if "," in nflag:
-                start, end = nflag.split(",")
-                self.from_animation_number = int(start)
-                self.upto_animation_number = int(end)
-            else:
-                self.from_animation_number = int(nflag)
+        if nflag:
+            self.from_animation_number = nflag[0]
+            try:
+                self.upto_animation_number = nflag[1]
+            except Exception:
+                logging.getLogger("manim").info(
+                    f"No end scene number specified in -n option. Rendering from {nflag[0]} onwards..."
+                )
 
         # Handle the quality flags
         self.quality = _determine_quality(args)
 
         # Handle the -r flag.
         rflag = args.resolution
-        if rflag is not None:
-            try:
-                h, w = rflag.split(",")
-                self.pixel_height = int(h)
-                self.pixel_width = int(w)
-            except ValueError:
-                raise ValueError(
-                    f'invalid argument {rflag} for -r flag (must have a comma ",")'
-                )
+        if rflag:
+            self.pixel_width = int(rflag[0])
+            self.pixel_height = int(rflag[1])
+
+        fps = args.frame_rate
+        if fps:
+            self.frame_rate = float(fps)
 
         # Handle --custom_folders
         if args.custom_folders:
@@ -705,7 +702,7 @@ class ManimConfig(MutableMapping):
                 "partial_movie_dir",
             ]:
                 self[opt] = self._parser["custom_folders"].get(opt, raw=True)
-            # --media_dir overrides the deaful.cfg file
+            # --media_dir overrides the default.cfg file
             if hasattr(args, "media_dir") and args.media_dir:
                 self.media_dir = args.media_dir
 
@@ -713,7 +710,7 @@ class ManimConfig(MutableMapping):
         if args.tex_template:
             self.tex_template = TexTemplateFromFile(tex_filename=args.tex_template)
 
-        if self.use_opengl_renderer:
+        if self.renderer == "opengl":
             if getattr(args, "write_to_movie") is None:
                 # --write_to_movie was not passed on the command line, so don't generate video.
                 self["write_to_movie"] = False
@@ -776,16 +773,12 @@ class ManimConfig(MutableMapping):
 
     progress_bar = property(
         lambda self: self._d["progress_bar"],
-        lambda self, val: self._set_boolean("progress_bar", val),
+        lambda self, val: self._set_from_list(
+            "progress_bar", val, ["none", "display", "leave"]
+        ),
         doc="Whether to show progress bars while rendering animations.",
     )
 
-    leave_progress_bars = property(
-        lambda self: self._d["leave_progress_bars"],
-        lambda self, val: self._set_boolean("leave_progress_bars", val),
-        doc="Whether to leave the progress bar for each animation.",
-    )
-
     @property
     def log_to_file(self):
         """Whether to save logs to a file."""
@@ -800,10 +793,10 @@ class ManimConfig(MutableMapping):
                 os.makedirs(log_dir)
             set_file_logger(self, self["verbosity"])
 
-    sound = property(
-        lambda self: self._d["sound"],
-        lambda self, val: self._set_boolean("sound", val),
-        doc="Whether to play a sound to notify when a scene is rendered (no flag).",
+    notify_outdated_version = property(
+        lambda self: self._d["notify_outdated_version"],
+        lambda self, val: self._set_boolean("notify_outdated_version", val),
+        doc="Whether to notify if there is a version update available.",
     )
 
     write_to_movie = property(
@@ -851,6 +844,20 @@ class ManimConfig(MutableMapping):
         )
         logging.getLogger("manim").setLevel(val)
 
+    @property
+    def format(self):
+        """File format; "png", "gif", "mp4", or "mov"."""
+        return self._d["format"]
+
+    @format.setter
+    def format(self, val: str) -> None:
+        """File format the renderer will output."""
+        self._set_from_list(
+            "format",
+            val,
+            [None, "png", "gif", "mp4", "mov"],
+        )
+
     ffmpeg_loglevel = property(
         lambda self: self._d["ffmpeg_loglevel"],
         lambda self, val: self._set_from_list(
@@ -935,7 +942,7 @@ class ManimConfig(MutableMapping):
     frame_rate = property(
         lambda self: self._d["frame_rate"],
         lambda self, val: self._d.__setitem__("frame_rate", val),
-        doc="Frame rate in frames per second (-q).",
+        doc="Frame rate in frames per second.",
     )
 
     background_color = property(
@@ -1065,6 +1072,20 @@ class ManimConfig(MutableMapping):
                 "save_last_frame, save_pngs, or save_as_gif)"
             )
 
+    @property
+    def renderer(self):
+        """Renderer: "cairo", "opengl", "webgl"""
+        return self._d["renderer"]
+
+    @renderer.setter
+    def renderer(self, val: str) -> None:
+        """Renderer for animations."""
+        self._set_from_list(
+            "renderer",
+            val,
+            ["cairo", "opengl", "webgl"],
+        )
+
     @property
     def use_opengl_renderer(self):
         """Whether or not to use the OpenGL renderer."""
@@ -1073,6 +1094,12 @@ class ManimConfig(MutableMapping):
     @use_opengl_renderer.setter
     def use_opengl_renderer(self, val: bool) -> None:
         self._d["use_opengl_renderer"] = val
+        if val:
+            self._set_from_list(
+                "renderer",
+                "opengl",
+                ["cairo", "opengl", "webgl"],
+            )
 
     @property
     def use_webgl_renderer(self):
@@ -1083,6 +1110,11 @@ class ManimConfig(MutableMapping):
     def use_webgl_renderer(self, val: bool) -> None:
         self._d["use_webgl_renderer"] = val
         if val:
+            self._set_from_list(
+                "renderer",
+                "webgl",
+                ["cairo", "opengl", "webgl"],
+            )
             self["disable_caching"] = True
 
     webgl_renderer_path = property(
@@ -1091,12 +1123,6 @@ class ManimConfig(MutableMapping):
         doc="Path to WebGL renderer.",
     )
 
-    webgl_updater_fps = property(
-        lambda self: self._d["webgl_updater_fps"],
-        lambda self, val: self._d.__setitem__("webgl_updater_fps", val),
-        doc="Frame rate to use when generating keyframe data for animations that use updaters while using the WebGL frontend.",
-    )
-
     media_dir = property(
         lambda self: self._d["media_dir"],
         lambda self, val: self._set_dir("media_dir", val),
@@ -1145,7 +1171,7 @@ class ManimConfig(MutableMapping):
         i.e. it is a subfolder of wherever ``config.media_dir`` is located.  In
         order to get the *actual* directory, use :meth:`~ManimConfig.get_dir`.
 
-        .. code-block:: python
+        .. code-block:: pycon
 
             >>> from manim import config
             >>> config.tex_dir
@@ -1158,9 +1184,9 @@ class ManimConfig(MutableMapping):
         Resolving directories is done in a lazy way, at the last possible
         moment, to reflect any changes in other config options:
 
-        .. code-block:: python
+        .. code-block:: pycon
 
-            >>> config.media_dir = 'my_media_dir'
+            >>> config.media_dir = "my_media_dir"
             >>> config.get_dir("tex_dir").as_posix()
             'my_media_dir/Tex'
 
@@ -1169,7 +1195,7 @@ class ManimConfig(MutableMapping):
         includes the name of the input file and the video quality
         (e.g. 480p15). This informamtion has to be supplied via ``kwargs``:
 
-        .. code-block:: python
+        .. code-block:: pycon
 
             >>> config.video_dir
             '{media_dir}/videos/{module_name}/{quality}'
@@ -1177,7 +1203,7 @@ class ManimConfig(MutableMapping):
             Traceback (most recent call last):
             KeyError: 'video_dir {media_dir}/videos/{module_name}/{quality} requires the following keyword arguments: module_name'
             >>> config.get_dir("video_dir", module_name="myfile").as_posix()
-            'my_media_dir/videos/myfile/1080p60'
+            'my_media_dir/videos/myfile/1080p60.0'
 
         Note the quality does not need to be passed as keyword argument since
         :class:`ManimConfig` does store information about quality.
@@ -1186,27 +1212,29 @@ class ManimConfig(MutableMapping):
         ``partial_movie_dir`` depends on ``video_dir``, which in turn depends
         on ``media_dir``:
 
-        .. code-block:: python
+        .. code-block:: pycon
 
             >>> config.partial_movie_dir
             '{video_dir}/partial_movie_files/{scene_name}'
             >>> config.get_dir("partial_movie_dir")
             Traceback (most recent call last):
             KeyError: 'partial_movie_dir {video_dir}/partial_movie_files/{scene_name} requires the following keyword arguments: scene_name'
-            >>> config.get_dir("partial_movie_dir", module_name="myfile", scene_name="myscene").as_posix()
-            'my_media_dir/videos/myfile/1080p60/partial_movie_files/myscene'
+            >>> config.get_dir(
+            ...     "partial_movie_dir", module_name="myfile", scene_name="myscene"
+            ... ).as_posix()
+            'my_media_dir/videos/myfile/1080p60.0/partial_movie_files/myscene'
 
         Standard f-string syntax is used.  Arbitrary names can be used when
         defining directories, as long as the corresponding values are passed to
         :meth:`ManimConfig.get_dir` via ``kwargs``.
 
-        .. code-block:: python
+        .. code-block:: pycon
 
             >>> config.media_dir = "{dir1}/{dir2}"
             >>> config.get_dir("media_dir")
             Traceback (most recent call last):
             KeyError: 'media_dir {dir1}/{dir2} requires the following keyword arguments: dir1'
-            >>> config.get_dir("media_dir", dir1='foo', dir2='bar').as_posix()
+            >>> config.get_dir("media_dir", dir1="foo", dir2="bar").as_posix()
             'foo/bar'
             >>> config.media_dir = "./media"
             >>> config.get_dir("media_dir").as_posix()
@@ -1248,7 +1276,6 @@ class ManimConfig(MutableMapping):
                     + "keyword arguments: "
                     + " ".join(exc.args)
                 ) from exc
-
         return Path(path) if path else None
 
     def _set_dir(self, key: str, val: typing.Union[str, Path]):
@@ -1331,7 +1358,7 @@ class ManimConfig(MutableMapping):
             if fn:
                 self._tex_template = TexTemplateFromFile(filename=fn)
             else:
-                self._tex_template = TexTemplate()
+                self._tex_template = TexTemplateLibrary.default.copy()
         return self._tex_template
 
     @tex_template.setter
