@@ -1,16 +1,20 @@
 """Tools for displaying multiple animations at once."""
-import typing
+
+
+from typing import TYPE_CHECKING, Callable, Optional, Union
 
 import numpy as np
 
+from .._config import config
 from ..animation.animation import Animation, prepare_animation
 from ..mobject.mobject import Group, Mobject
+from ..mobject.opengl_mobject import OpenGLGroup
 from ..scene.scene import Scene
-from ..utils.bezier import interpolate
 from ..utils.iterables import remove_list_redundancies
 from ..utils.rate_functions import linear
 
-if typing.TYPE_CHECKING:
+if TYPE_CHECKING:
+    from ..mobject.types.opengl_vectorized_mobject import OpenGLVGroup
     from ..mobject.types.vectorized_mobject import VGroup
 
 __all__ = ["AnimationGroup", "Succession", "LaggedStart", "LaggedStartMap"]
@@ -23,32 +27,28 @@ class AnimationGroup(Animation):
     def __init__(
         self,
         *animations: Animation,
-        group: typing.Union[Group, "VGroup"] = None,
-        run_time: float = None,
-        rate_func: typing.Callable[[float], float] = linear,
+        group: Union[Group, "VGroup", OpenGLGroup, "OpenGLVGroup"] = None,
+        run_time: Optional[float] = None,
+        rate_func: Callable[[float], float] = linear,
         lag_ratio: float = 0,
         **kwargs
     ) -> None:
         self.animations = [prepare_animation(anim) for anim in animations]
         self.group = group
         if self.group is None:
-            self.group = Group(
-                *remove_list_redundancies(
-                    [anim.mobject for anim in self.animations if not anim.is_dummy()]
-                )
+            mobjects = remove_list_redundancies(
+                [anim.mobject for anim in self.animations]
             )
+            if config["renderer"] == "opengl":
+                self.group = OpenGLGroup(*mobjects)
+            else:
+                self.group = Group(*mobjects)
         super().__init__(self.group, rate_func=rate_func, lag_ratio=lag_ratio, **kwargs)
-        self.run_time = run_time
-        self.init_run_time()
+        self.run_time: float = self.init_run_time(run_time)
 
     def get_all_mobjects(self) -> Group:
         return self.group
 
-    def get_run_time(self) -> float:
-        if super().get_run_time() is None:
-            self.init_run_time()
-        return super().get_run_time()
-
     def begin(self) -> None:
         for anim in self.animations:
             anim.begin()
@@ -65,13 +65,13 @@ class AnimationGroup(Animation):
         for anim in self.animations:
             anim.update_mobjects(dt)
 
-    def init_run_time(self) -> None:
+    def init_run_time(self, run_time) -> float:
         self.build_animations_with_timings()
         if self.anims_with_timings:
             self.max_end_time = np.max([awt[2] for awt in self.anims_with_timings])
         else:
             self.max_end_time = 0
-        self.run_time = self.max_end_time if self.run_time is None else self.run_time
+        return self.max_end_time if run_time is None else run_time
 
     def build_animations_with_timings(self) -> None:
         """
@@ -79,14 +79,13 @@ class AnimationGroup(Animation):
         (anim, start_time, end_time)
         """
         self.anims_with_timings = []
-        curr_time = 0
+        curr_time: float = 0
         for anim in self.animations:
-            start_time = curr_time
-            end_time = start_time + anim.get_run_time()
+            start_time: float = curr_time
+            end_time: float = start_time + anim.get_run_time()
             self.anims_with_timings.append((anim, start_time, end_time))
-            # Start time of next animation is based on
-            # the lag_ratio
-            curr_time = interpolate(start_time, end_time, self.lag_ratio)
+            # Start time of next animation is based on the lag_ratio
+            curr_time = (1 - self.lag_ratio) * start_time + self.lag_ratio * end_time
 
     def interpolate(self, alpha: float) -> None:
         # Note, if the run_time of AnimationGroup has been
@@ -110,7 +109,6 @@ class Succession(AnimationGroup):
 
     def begin(self) -> None:
         assert len(self.animations) > 0
-        self.init_run_time()
         self.update_active_animation(0)
 
     def finish(self) -> None:
@@ -124,9 +122,9 @@ class Succession(AnimationGroup):
     def update_active_animation(self, index: int) -> None:
         self.active_index = index
         if index >= len(self.animations):
-            self.active_animation = None
-            self.active_start_time = None
-            self.active_end_time = None
+            self.active_animation: Optional[Animation] = None
+            self.active_start_time: Optional[float] = None
+            self.active_end_time: Optional[float] = None
         else:
             self.active_animation = self.animations[index]
             self.active_animation.begin()
@@ -134,14 +132,15 @@ class Succession(AnimationGroup):
             self.active_end_time = self.anims_with_timings[index][2]
 
     def next_animation(self) -> None:
-        self.active_animation.finish()
+        if self.active_animation is not None:
+            self.active_animation.finish()
         self.update_active_animation(self.active_index + 1)
 
     def interpolate(self, alpha: float) -> None:
-        current_time = interpolate(0, self.run_time, alpha)
+        current_time = alpha * self.run_time
         while self.active_end_time is not None and current_time >= self.active_end_time:
             self.next_animation()
-        if self.active_animation:
+        if self.active_animation is not None and self.active_start_time is not None:
             elapsed = current_time - self.active_start_time
             active_run_time = self.active_animation.get_run_time()
             subalpha = elapsed / active_run_time if active_run_time != 0.0 else 1.0
@@ -161,9 +160,9 @@ class LaggedStart(AnimationGroup):
 class LaggedStartMap(LaggedStart):
     def __init__(
         self,
-        AnimationClass: Animation,
+        AnimationClass: Callable[..., Animation],
         mobject: Mobject,
-        arg_creator: typing.Callable[[Mobject], str] = None,
+        arg_creator: Callable[[Mobject], str] = None,
         run_time: float = 2,
         **kwargs
     ) -> None:
