@@ -4,9 +4,13 @@ __all__ = ["UpdateFromFunc", "UpdateFromAlphaFunc", "MaintainPositionRelativeTo"
 
 
 import operator as op
+import typing
 
 from ..animation.animation import Animation
 
+if typing.TYPE_CHECKING:
+    from ..mobject.mobject import Mobject
+
 
 class UpdateFromFunc(Animation):
     """
@@ -15,25 +19,31 @@ class UpdateFromFunc(Animation):
     on another simultaneously animated mobject
     """
 
-    CONFIG = {
-        "suspend_mobject_updating": False,
-    }
-
-    def __init__(self, mobject, update_function, **kwargs):
+    def __init__(
+        self,
+        mobject: "Mobject",
+        update_function: typing.Callable[["Mobject"], typing.Any],
+        suspend_mobject_updating: bool = False,
+        **kwargs
+    ) -> None:
         self.update_function = update_function
-        super().__init__(mobject, **kwargs)
+        super().__init__(
+            mobject, suspend_mobject_updating=suspend_mobject_updating, **kwargs
+        )
 
-    def interpolate_mobject(self, alpha):
+    def interpolate_mobject(self, alpha: float) -> None:
         self.update_function(self.mobject)
 
 
 class UpdateFromAlphaFunc(UpdateFromFunc):
-    def interpolate_mobject(self, alpha):
+    def interpolate_mobject(self, alpha: float) -> None:
         self.update_function(self.mobject, alpha)
 
 
 class MaintainPositionRelativeTo(Animation):
-    def __init__(self, mobject, tracked_mobject, **kwargs):
+    def __init__(
+        self, mobject: "Mobject", tracked_mobject: "Mobject", **kwargs
+    ) -> None:
         self.tracked_mobject = tracked_mobject
         self.diff = op.sub(
             mobject.get_center(),
@@ -41,7 +51,7 @@ class MaintainPositionRelativeTo(Animation):
         )
         super().__init__(mobject, **kwargs)
 
-    def interpolate_mobject(self, alpha):
+    def interpolate_mobject(self, alpha: float) -> None:
         target = self.tracked_mobject.get_center()
         location = self.mobject.get_center()
         self.mobject.shift(target - location + self.diff)
