@@ -3,30 +3,31 @@
 
 __all__ = ["Camera", "BackgroundColoredVMobjectDisplayer"]
 
-from functools import reduce
+import copy
 import itertools as it
 import operator as op
+import pathlib
 import time
-import copy
+from functools import reduce
+from typing import Union
 
-from PIL import Image
-from scipy.spatial.distance import pdist
 import cairo
 import numpy as np
+from PIL import Image
+from scipy.spatial.distance import pdist
 
-from .. import logger, config
+from .. import config, logger
 from ..constants import *
-from ..mobject.types.image_mobject import AbstractImageMobject
 from ..mobject.mobject import Mobject
+from ..mobject.types.image_mobject import AbstractImageMobject
 from ..mobject.types.point_cloud_mobject import PMobject
 from ..mobject.types.vectorized_mobject import VMobject
 from ..utils.color import color_to_int_rgba
+from ..utils.family import extract_mobject_family_members
 from ..utils.images import get_full_raster_image_path
 from ..utils.iterables import list_difference_update
 from ..utils.simple_functions import fdiv
 from ..utils.space_ops import angle_of_vector
-from ..utils.space_ops import get_norm
-from ..utils.family import extract_mobject_family_members
 
 
 class Camera:
@@ -574,11 +575,9 @@ class Camera:
         """
         if len(vmobjects) == 0:
             return
-        batch_file_pairs = it.groupby(
-            vmobjects, lambda vm: vm.get_background_image_file()
-        )
-        for file_name, batch in batch_file_pairs:
-            if file_name:
+        batch_image_pairs = it.groupby(vmobjects, lambda vm: vm.get_background_image())
+        for image, batch in batch_image_pairs:
+            if image:
                 self.display_multiple_background_colored_vmobjects(batch, pixel_array)
             else:
                 self.display_multiple_non_background_colored_vmobjects(
@@ -891,7 +890,7 @@ class Camera:
         for image_mobject in image_mobjects:
             self.display_image_mobject(image_mobject, pixel_array)
 
-    def display_image_mobject(self, image_mobject, pixel_array):
+    def display_image_mobject(self, image_mobject: AbstractImageMobject, pixel_array):
         """Displays an ImageMobject by changing the pixel_array suitably.
 
         Parameters
@@ -913,7 +912,7 @@ class Camera:
         pixel_width = max(int(pdist([ul_coords, ur_coords])), 1)
         pixel_height = max(int(pdist([ul_coords, dl_coords])), 1)
         sub_image = sub_image.resize(
-            (pixel_width, pixel_height), resample=Image.BICUBIC
+            (pixel_width, pixel_height), resample=image_mobject.resampling_algorithm
         )
 
         # Rotate
@@ -921,7 +920,7 @@ class Camera:
         adjusted_angle = -int(360 * angle / TAU)
         if adjusted_angle != 0:
             sub_image = sub_image.rotate(
-                adjusted_angle, resample=Image.BICUBIC, expand=1
+                adjusted_angle, resample=image_mobject.resampling_algorithm, expand=1
             )
 
         # TODO, there is no accounting for a shear...
@@ -986,7 +985,7 @@ class Camera:
         """
         if not np.any(points > self.max_allowable_norm):
             return points
-        norms = np.apply_along_axis(get_norm, 1, points)
+        norms = np.apply_along_axis(np.linalg.norm, 1, points)
         violator_indices = norms > self.max_allowable_norm
         violators = points[violator_indices, :]
         violator_norms = norms[violator_indices]
@@ -1209,30 +1208,33 @@ class BackgroundColoredVMobjectDisplayer:
         mode = "RGBA" if pixel_array.shape[2] == 4 else "RGB"
         return self.resize_background_array(background_array, width, height, mode)
 
-    def get_background_array(self, file_name):
+    def get_background_array(self, image: Union[Image.Image, pathlib.Path, str]):
         """Gets the background array that has the passed file_name.
 
         Parameters
         ----------
-        file_name : str
-            The file_name of the background image.
+        image
+            The background image or its file name.
 
         Returns
         -------
         np.ndarray
-            The pixel array of the file whose file name is `file_name`
+            The pixel array of the image.
         """
-        if file_name in self.file_name_to_pixel_array_map:
-            return self.file_name_to_pixel_array_map[file_name]
-        full_path = get_full_raster_image_path(file_name)
-        image = Image.open(full_path)
+        image_key = str(image)
+
+        if image_key in self.file_name_to_pixel_array_map:
+            return self.file_name_to_pixel_array_map[image_key]
+        if isinstance(image, str):
+            full_path = get_full_raster_image_path(image)
+            image = Image.open(full_path)
         back_array = np.array(image)
 
         pixel_array = self.pixel_array
         if not np.all(pixel_array.shape == back_array.shape):
             back_array = self.resize_background_array_to_match(back_array, pixel_array)
 
-        self.file_name_to_pixel_array_map[file_name] = back_array
+        self.file_name_to_pixel_array_map[image_key] = back_array
         return back_array
 
     def display(self, *cvmobjects):
@@ -1248,12 +1250,10 @@ class BackgroundColoredVMobjectDisplayer:
         np.array
             The pixel array with the `cvmobjects` displayed.
         """
-        batch_image_file_pairs = it.groupby(
-            cvmobjects, lambda cv: cv.get_background_image_file()
-        )
+        batch_image_pairs = it.groupby(cvmobjects, lambda cv: cv.get_background_image())
         curr_array = None
-        for batch, image_file in batch_image_file_pairs:
-            background_array = self.get_background_array(image_file)
+        for image, batch in batch_image_pairs:
+            background_array = self.get_background_array(image)
             pixel_array = self.pixel_array
             self.camera.display_multiple_non_background_colored_vmobjects(
                 batch, pixel_array
