@@ -16,16 +16,27 @@ from ..utils.color import BLACK
 
 class ScreenRectangle(Rectangle):
     def __init__(self, aspect_ratio=16.0 / 9.0, height=4, **kwargs):
-        self.aspect_ratio = aspect_ratio
-        self.height = height
-        Rectangle.__init__(self, **kwargs)
-        self.set_width(self.aspect_ratio * self.get_height(), stretch=True)
+        Rectangle.__init__(self, width=aspect_ratio * height, height=height, **kwargs)
+
+    @property
+    def aspect_ratio(self):
+        """The aspect ratio.
+
+        When set, the width is stretched to accommodate
+        the new aspect ratio.
+        """
+
+        return self.width / self.height
+
+    @aspect_ratio.setter
+    def aspect_ratio(self, value):
+        self.stretch_to_fit_width(value * self.height)
 
 
 class FullScreenRectangle(ScreenRectangle):
     def __init__(self, **kwargs):
         ScreenRectangle.__init__(self, **kwargs)
-        self.set_height(config["frame_height"])
+        self.height = config["frame_height"]
 
 
 class FullScreenFadeRectangle(FullScreenRectangle):
@@ -41,8 +52,18 @@ class FullScreenFadeRectangle(FullScreenRectangle):
 
 class PictureInPictureFrame(Rectangle):
     def __init__(self, height=3, aspect_ratio=16.0 / 9.0, **kwargs):
-        self.height = height
-        self.aspect_ratio = aspect_ratio
-        Rectangle.__init__(
-            self, width=self.aspect_ratio * self.height, height=self.height, **kwargs
-        )
+        Rectangle.__init__(self, width=aspect_ratio * height, height=height, **kwargs)
+
+    @property
+    def aspect_ratio(self):
+        """The aspect ratio.
+
+        When set, the width is stretched to accommodate
+        the new aspect ratio.
+        """
+
+        return self.width / self.height
+
+    @aspect_ratio.setter
+    def aspect_ratio(self, value):
+        self.stretch_to_fit_width(value * self.height)
