@@ -32,7 +32,6 @@ __all__ = [
     "Dot",
     "AnnotationDot",
     "LabeledDot",
-    "SmallDot",
     "Ellipse",
     "AnnularSector",
     "Sector",
@@ -59,27 +58,27 @@ __all__ = [
     "RightAngle",
 ]
 
-import warnings
-import numpy as np
 import math
+import warnings
+from typing import Sequence
 
+import numpy as np
+
+from .. import logger
 from ..constants import *
 from ..mobject.mobject import Mobject
-from ..mobject.types.vectorized_mobject import VGroup
-from ..mobject.types.vectorized_mobject import VMobject
-from ..mobject.types.vectorized_mobject import DashedVMobject
-from ..utils.iterables import adjacent_n_tuples
-from ..utils.iterables import adjacent_pairs
-from ..utils.simple_functions import fdiv
-from ..utils.space_ops import angle_of_vector
-from ..utils.space_ops import angle_between_vectors
-from ..utils.space_ops import compass_directions
-from ..utils.space_ops import line_intersection
-from ..utils.space_ops import get_norm
-from ..utils.space_ops import normalize
-from ..utils.space_ops import rotate_vector
+from ..mobject.types.vectorized_mobject import DashedVMobject, VGroup, VMobject
 from ..utils.color import *
-from .. import logger
+from ..utils.iterables import adjacent_n_tuples, adjacent_pairs
+from ..utils.simple_functions import fdiv
+from ..utils.space_ops import (
+    angle_between_vectors,
+    angle_of_vector,
+    compass_directions,
+    line_intersection,
+    normalize,
+    rotate_vector,
+)
 
 
 class TipableVMobject(VMobject):
@@ -252,7 +251,7 @@ class TipableVMobject(VMobject):
 
     def get_length(self):
         start, end = self.get_start_and_end()
-        return get_norm(start - end)
+        return np.linalg.norm(start - end)
 
 
 class Arc(TipableVMobject):
@@ -260,9 +259,9 @@ class Arc(TipableVMobject):
 
     def __init__(
         self,
+        radius: float = 1.0,
         start_angle=0,
         angle=TAU / 4,
-        radius=1.0,
         num_components=9,
         anchors_span_full_range=True,
         arc_center=ORIGIN,
@@ -421,10 +420,16 @@ class Circle(Arc):
     """
 
     def __init__(
-        self, color=RED, close_new_points=True, anchors_span_full_range=False, **kwargs
+        self,
+        radius: float = None,
+        color=RED,
+        close_new_points=True,
+        anchors_span_full_range=False,
+        **kwargs
     ):
         Arc.__init__(
             self,
+            radius=radius,
             start_angle=0,
             angle=TAU,
             color=color,
@@ -550,7 +555,7 @@ class Dot(Circle):
     def __init__(
         self,
         point=ORIGIN,
-        radius=DEFAULT_DOT_RADIUS,
+        radius: float = DEFAULT_DOT_RADIUS,
         stroke_width=0,
         fill_opacity=1.0,
         color=WHITE,
@@ -567,17 +572,6 @@ class Dot(Circle):
         )
 
 
-class SmallDot(Dot):
-    """Deprecated - A dot with small radius"""
-
-    def __init__(self, radius=DEFAULT_SMALL_DOT_RADIUS, **kwargs):
-        logger.warning(
-            "SmallDot has been deprecated and will be removed in a future release. "
-            "Use Dot instead."
-        )
-        Dot.__init__(self, radius=radius, **kwargs)
-
-
 class AnnotationDot(Dot):
     """
     A dot with bigger radius and bold stroke to annotate scenes.
@@ -585,7 +579,7 @@ class AnnotationDot(Dot):
 
     def __init__(
         self,
-        radius=DEFAULT_DOT_RADIUS * 1.3,
+        radius: float = DEFAULT_DOT_RADIUS * 1.3,
         stroke_width=5,
         stroke_color=WHITE,
         fill_color=BLUE,
@@ -819,7 +813,27 @@ class Line(TipableVMobject):
                 return mob.get_boundary_point(direction)
         return np.array(mob_or_point)
 
-    def put_start_and_end_on(self, start, end):
+    def put_start_and_end_on(self, start: Sequence[float], end: Sequence[float]):
+        """Sets starts and end coordinates of a line.
+        Examples
+        --------
+        .. manim:: LineExample
+
+            class LineExample(Scene):
+                def construct(self):
+                    d = VGroup()
+                    for i in range(0,10):
+                        d.add(Dot())
+                    d.arrange_in_grid(buff=1)
+                    self.add(d)
+                    l= Line(d[0], d[1])
+                    self.add(l)
+                    self.wait()
+                    l.put_start_and_end_on(d[1].get_center(), d[2].get_center())
+                    self.wait()
+                    l.put_start_and_end_on(d[4].get_center(), d[7].get_center())
+                    self.wait()
+        """
         curr_start, curr_end = self.get_start_and_end()
         if np.all(curr_start == curr_end):
             # TODO, any problems with resetting
@@ -838,6 +852,21 @@ class Line(TipableVMobject):
     def get_angle(self):
         return angle_of_vector(self.get_vector())
 
+    def get_projection(self, point):
+        """Return the projection of a point onto the line.
+
+        Examples
+        --------
+        ::
+            >>> import numpy as np
+            >>> line = Line(LEFT, RIGHT)
+            >>> line.get_projection(np.array([0, 1, 0]))
+            array([0., 0., 0.])
+        """
+        unit_vect = self.get_unit_vector()
+        start = self.get_start()
+        return start + np.dot(point - start, unit_vect) * unit_vect
+
     def get_slope(self):
         return np.tan(self.get_angle())
 
@@ -1166,8 +1195,9 @@ class Arrow(Line):
 
             >>> arrow = Arrow(np.array([-1, -1, 0]), np.array([1, 1, 0]), buff=0)
             >>> scaled_arrow = arrow.scale(2)
-            >>> scaled_arrow.get_start_and_end()
-            (array([-2., -2.,  0.]), array([2., 2., 0.]))
+            >>> np.round(scaled_arrow.get_start_and_end(), 8) + 0
+            array([[-2., -2.,  0.],
+                   [ 2.,  2.,  0.]])
             >>> arrow.tip.length == scaled_arrow.tip.length
             True
 
@@ -1278,6 +1308,58 @@ class Vector(Arrow):
             direction = np.append(np.array(direction), 0)
         Arrow.__init__(self, ORIGIN, direction, buff=buff, **kwargs)
 
+    def coordinate_label(
+        self, integer_labels: bool = True, n_dim: int = 2, color: str = WHITE
+    ):
+        """Creates a label based on the coordinates of the vector.
+
+        Parameters
+        ----------
+        integer_labels
+            Whether or not to round the coordinates to integers.
+        n_dim
+            The number of dimensions of the vector.
+        color
+            The color of the label.
+
+        Examples
+        --------
+
+        .. manim VectorCoordinateLabel
+            :save_last_frame:
+
+            class VectorCoordinateLabel(Scene):
+                def construct(self):
+                    plane = NumberPlane()
+
+                    vect_1 = Vector([1, 2])
+                    vect_2 = Vector([-3, -2])
+                    label_1 = vect1.coordinate_label()
+                    label_2 = vect2.coordinate_label(color=YELLOW)
+
+                    self.add(plane, vect_1, vect_2, label_1, label_2)
+        """
+        # avoiding circular imports
+        from .matrix import Matrix
+
+        vect = np.array(self.get_end())
+        if integer_labels:
+            vect = np.round(vect).astype(int)
+        vect = vect[:n_dim]
+        vect = vect.reshape((n_dim, 1))
+
+        label = Matrix(vect)
+        label.scale(LARGE_BUFF - 0.2)
+
+        shift_dir = np.array(self.get_end())
+        if shift_dir[0] >= 0:  # Pointing right
+            shift_dir -= label.get_left() + DEFAULT_MOBJECT_TO_MOBJECT_BUFFER * LEFT
+        else:  # Pointing left
+            shift_dir -= label.get_right() + DEFAULT_MOBJECT_TO_MOBJECT_BUFFER * RIGHT
+        label.shift(shift_dir)
+        label.set_color(color)
+        return label
+
 
 class DoubleArrow(Arrow):
     """An arrow with tips on both ends.
@@ -1394,10 +1476,10 @@ class Polygon(VMobject):
             >>> sq = Square()
             >>> points = sq.get_vertices()
             >>> points
-            array([[-1.,  1.,  0.],
-                   [ 1.,  1.,  0.],
-                   [ 1., -1.,  0.],
-                   [-1., -1.,  0.]])
+            array([[ 1.,  1.,  0.],
+                   [-1.,  1.,  0.],
+                   [-1., -1.,  0.],
+                   [ 1., -1.,  0.]])
 
         Returns
         -------
@@ -1820,7 +1902,7 @@ class Rectangle(Polygon):
     ):
         self.mark_paths_closed = mark_paths_closed
         self.close_new_points = close_new_points
-        Polygon.__init__(self, UL, UR, DR, DL, color=color, **kwargs)
+        Polygon.__init__(self, UR, UL, DL, DR, color=color, **kwargs)
         self.stretch_to_fit_width(width)
         self.stretch_to_fit_height(height)
 
@@ -2034,7 +2116,7 @@ class ArrowTip(VMobject):
             0.35
 
         """
-        return get_norm(self.vector)
+        return np.linalg.norm(self.vector)
 
 
 class ArrowTriangleTip(ArrowTip, Triangle):
@@ -2270,6 +2352,27 @@ class Angle(Arc, Elbow):
                 self.add(
                     line_list
                 )
+    .. manim:: FilledAngle
+        :save_last_frame:
+
+        class FilledAngle(Scene):
+            def construct(self):
+                l1 = Line(ORIGIN, 2 * UP + RIGHT).set_color(GREEN)
+                l2 = (
+                    Line(ORIGIN, 2 * UP + RIGHT)
+                    .set_color(GREEN)
+                    .rotate(-20 * DEGREES, about_point=ORIGIN)
+                )
+                norm = l1.get_length()
+                a1 = Angle(l1, l2, other_angle=True, radius=norm - 0.5).set_color(GREEN)
+                a2 = Angle(l1, l2, other_angle=True, radius=norm).set_color(GREEN)
+                q1 = a1.get_points() #  save all coordinates of points of angle a1
+                q2 = a2.reverse_direction().get_points()  #  save all coordinates of points of angle a1 (in reversed direction)
+                pnts = np.concatenate([q1, q2, q1[0].reshape(1, 3)])  # adds points and ensures that path starts and ends at same point
+                mfill = VMobject().set_color(ORANGE)
+                mfill.set_points_as_corners(pnts).set_fill(GREEN, opacity=1)
+                self.add(l1, l2)
+                self.add(mfill)
 
     """
 
