@@ -113,6 +113,37 @@ in this example where we set the color of the ``\bigstar`` using :func:`~.set_co
             tex.set_color_by_tex('igsta', RED)
             self.add(tex)
 
+Note that :func:`~.set_color_by_tex` colors the entire substring containing the Tex searched for,
+not just the specific symbol or Tex expression searched for. Consider the following example:
+
+.. manim:: IncorrectLaTeXSubstringColoring
+    :save_last_frame:
+
+    class IncorrectLaTeXSubstringColoring(Scene):
+        def construct(self):
+            equation = MathTex(
+                r"e^x = x^0 + x^1 + \frac{1}{2} x^2 + \frac{1}{6} x^3 + \cdots + \frac{1}{n!} x^n + \cdots"
+            )
+            equation.set_color_by_tex("x", YELLOW)
+            self.add(equation)
+
+As you can see, this colors the entire equation yellow, contrary to what may be expected. To color only ``x`` yellow, we have to do the following:
+
+.. manim:: CorrectLaTeXSubstringColoring
+    :save_last_frame:
+
+    class CorrectLaTeXSubstringColoring(Scene):
+        def construct(self):
+            equation = MathTex(
+                r"e^x = x^0 + x^1 + \frac{1}{2} x^2 + \frac{1}{6} x^3 + \cdots + \frac{1}{n!} x^n + \cdots",
+                substrings_to_isolate="x"
+            )
+            equation.set_color_by_tex("x", YELLOW)
+            self.add(equation)
+
+By setting ``substring_to_isolate`` to ``x``, we split up the :class:`~.MathTex` into substrings
+automatically and isolate ``x`` components into individual substrings. Only then can :meth:`~.set_color_by_tex` be used to achieve the desired result.
+
 LaTeX Maths Fonts - The Template Library
 ++++++++++++++++++++++++++++++++++++++++
 Changing fonts in LaTeX when typesetting mathematical formulae is a little bit more tricky than
@@ -163,28 +194,25 @@ __all__ = [
     "Tex",
     "BulletedList",
     "Title",
-    "TexMobject",
-    "TextMobject",
 ]
 
 
-from functools import reduce
-import operator as op
 import itertools as it
+import operator as op
 import re
+from functools import reduce
+from textwrap import dedent
 
-from .style_utils import parse_style
 from ... import config, logger
 from ...constants import *
 from ...mobject.geometry import Line
 from ...mobject.svg.svg_mobject import SVGMobject
 from ...mobject.svg.svg_path import SVGPathMobject
-from ...mobject.types.vectorized_mobject import VGroup
-from ...mobject.types.vectorized_mobject import VectorizedPoint
-from ...utils.strings import split_string_list_to_isolate_substrings
-from ...utils.tex_file_writing import tex_to_svg_file
+from ...mobject.types.vectorized_mobject import VectorizedPoint, VGroup
 from ...utils.color import BLACK
 from ...utils.tex import TexTemplate
+from ...utils.tex_file_writing import tex_to_svg_file
+from .style_utils import parse_style
 
 TEX_MOB_SCALE_FACTOR = 0.05
 
@@ -362,6 +390,15 @@ class MathTex(SingleStringMathTex):
         >>> MathTex('a^2 + b^2 = c^2')
         MathTex('a^2 + b^2 = c^2')
 
+    Check that double brace group splitting works correctly::
+
+        >>> t1 = MathTex('{{ a }} + {{ b }} = {{ c }}')
+        >>> len(t1.submobjects)
+        5
+        >>> t2 = MathTex(r"\frac{1}{a+b\sqrt{2}}")
+        >>> len(t2.submobjects)
+        1
+
     """
 
     def __init__(
@@ -382,27 +419,49 @@ class MathTex(SingleStringMathTex):
         if self.tex_to_color_map is None:
             self.tex_to_color_map = {}
         self.tex_environment = tex_environment
+        self.brace_notation_split_occurred = False
         tex_strings = self.break_up_tex_strings(tex_strings)
         self.tex_strings = tex_strings
-        SingleStringMathTex.__init__(
-            self,
-            self.arg_separator.join(tex_strings),
-            tex_environment=self.tex_environment,
-            tex_template=self.tex_template,
-            **kwargs,
-        )
-        self.break_up_by_substrings()
+        try:
+            SingleStringMathTex.__init__(
+                self,
+                self.arg_separator.join(tex_strings),
+                tex_environment=self.tex_environment,
+                tex_template=self.tex_template,
+                **kwargs,
+            )
+            self.break_up_by_substrings()
+        except ValueError as compilation_error:
+            if self.brace_notation_split_occurred:
+                logger.error(
+                    dedent(
+                        """\
+                        A group of double braces, {{ ... }}, was detected in
+                        your string. Manim splits TeX strings at the double
+                        braces, which might have caused the current
+                        compilation error. If you didn't use the double brace
+                        split intentionally, add spaces between the braces to
+                        avoid the automatic splitting: {{ ... }} --> { { ... } }.
+                        """
+                    )
+                )
+            raise compilation_error
         self.set_color_by_tex_to_color_map(self.tex_to_color_map)
 
         if self.organize_left_to_right:
             self.organize_submobjects_left_to_right()
 
     def break_up_tex_strings(self, tex_strings):
-        tex_strings = [str(t) for t in tex_strings]
         # Separate out anything surrounded in double braces
-        patterns = ["{{", "}}"]
+        pre_split_length = len(tex_strings)
+        tex_strings = [re.split("{{(.*?)}}", str(t)) for t in tex_strings]
+        tex_strings = sum(tex_strings, [])
+        if len(tex_strings) > pre_split_length:
+            self.brace_notation_split_occurred = True
+
         # Separate out any strings specified in the isolate
         # or tex_to_color_map lists.
+        patterns = []
         patterns.extend(
             [
                 "({})".format(re.escape(ss))
@@ -412,10 +471,13 @@ class MathTex(SingleStringMathTex):
             ]
         )
         pattern = "|".join(patterns)
-        pieces = []
-        for s in tex_strings:
-            pieces.extend(re.split(pattern, s))
-        return list(filter(lambda s: s, pieces))
+        if pattern:
+            pieces = []
+            for s in tex_strings:
+                pieces.extend(re.split(pattern, s))
+        else:
+            pieces = tex_strings
+        return [p for p in pieces if p]
 
     def break_up_by_substrings(self):
         """
@@ -585,21 +647,3 @@ class Title(Tex):
                 underline.width = underline_width
             self.add(underline)
             self.underline = underline
-
-
-class TexMobject(MathTex):
-    def __init__(self, *tex_strings, **kwargs):
-        logger.warning(
-            "TexMobject has been deprecated (due to its confusing name) "
-            "in favour of MathTex. Please use MathTex instead!"
-        )
-        MathTex.__init__(self, *tex_strings, **kwargs)
-
-
-class TextMobject(Tex):
-    def __init__(self, *text_parts, **kwargs):
-        logger.warning(
-            "TextMobject has been deprecated (due to its confusing name) "
-            "in favour of Tex. Please use Tex instead!"
-        )
-        Tex.__init__(self, *text_parts, **kwargs)
