@@ -5,8 +5,8 @@ __all__ = ["ValueTracker", "ExponentialValueTracker", "ComplexValueTracker"]
 
 import numpy as np
 
-from ..utils.paths import straight_path
 from ..mobject.mobject import Mobject
+from ..utils.paths import straight_path
 
 
 class ValueTracker(Mobject):
@@ -28,17 +28,38 @@ class ValueTracker(Mobject):
                 pointer = Vector(DOWN)
                 label = MathTex("x").add_updater(lambda m: m.next_to(pointer, UP))
 
-                pointer_value = ValueTracker(0)
+                pointer_tracker = ValueTracker(0)
                 pointer.add_updater(
                     lambda m: m.next_to(
-                                number_line.n2p(pointer_value.get_value()),
+                                number_line.n2p(pointer_tracker.get_value()),
                                 UP
                             )
                 )
                 self.add(number_line, pointer,label)
-                self.play(pointer_value.animate.set_value(5)),
-                self.wait()
-                self.play(pointer_value.animate.set_value(3))
+                pointer_tracker += 1.5
+                self.wait(1)
+                pointer_tracker -= 4
+                self.wait(0.5)
+                self.play(pointer_tracker.animate.set_value(5)),
+                self.wait(0.5)
+                self.play(pointer_tracker.animate.set_value(3))
+                self.play(pointer_tracker.animate.increment_value(-2))
+                self.wait(0.5)
+
+    .. note::
+
+        You can also link ValueTrackers to updaters. In this case, you have to make sure that the ValueTracker is added to the scene by ``add``
+
+    .. manim:: ValueTrackerExample
+
+        class ValueTrackerExample(Scene):
+            def construct(self):
+                pointer_tracker = ValueTracker(0)
+                label = Dot(radius=3).add_updater(lambda x : x.set_x(pointer_tracker.get_value()))
+                self.add(label)
+                self.add(pointer_tracker)
+                pointer_tracker.add_updater(lambda mobject, dt: mobject.increment_value(dt))
+                self.wait(2)
 
     """
 
@@ -47,20 +68,29 @@ class ValueTracker(Mobject):
         self.points = np.zeros((1, 3))
         self.set_value(value)
 
-    def get_value(self):
+    def get_value(self) -> float:
+        """Get the current value of the ValueTracker. This value changes continuously when :attr:`animate` for the ValueTracker is called."""
         return self.points[0, 0]
 
-    def set_value(self, value):
+    def set_value(self, value: float):
+        """Sets a new scalar value to the ValueTracker"""
         self.points[0, 0] = value
         return self
 
-    def increment_value(self, d_value):
+    def increment_value(self, d_value: float):
+        """Increments (adds) a scalar value  to the ValueTracker"""
         self.set_value(self.get_value() + d_value)
 
-    def __iadd__(self, d_value):
+    def __iadd__(self, d_value: float):
+        """adds ``+=`` syntax to increment the value of the ValueTracker"""
         self.increment_value(d_value)
         return self
 
+    def __isub__(self, d_value: float):
+        """adds ``-=`` syntax to decrement the value of the ValueTracker"""
+        self.increment_value(-d_value)
+        return self
+
     def interpolate(self, mobject1, mobject2, alpha, path_func=straight_path):
         """
         Turns self into an interpolation between mobject1
