@@ -1,7 +1,9 @@
 import copy
-from ..utils.family import extract_mobject_family_members
+
 from manim import config
 
+from ..utils.family import extract_mobject_family_members
+
 
 class WebGLRenderer:
     def __init__(self, frame_server):
@@ -60,4 +62,4 @@ class WebGLRenderer:
 class WebGLCamera:
     def __init__(self, use_z_index=True):
         self.use_z_index = use_z_index
-        self.frame_rate = config["webgl_updater_fps"]
+        self.frame_rate = config["frame_rate"]
