@@ -48,24 +48,28 @@ __all__ = ["GraphScene"]
 
 import itertools as it
 
-from .. import config
-from ..animation.creation import Write, DrawBorderThenFill, Create
+from .. import config, logger
+from ..animation.creation import Create, DrawBorderThenFill, Write
 from ..animation.transform import Transform
 from ..animation.update import UpdateFromAlphaFunc
 from ..constants import *
 from ..mobject.functions import ParametricFunction
-from ..mobject.geometry import Line
-from ..mobject.geometry import Rectangle
-from ..mobject.geometry import RegularPolygon
-from ..mobject.number_line import NumberLine
-from ..mobject.svg.tex_mobject import MathTex
-from ..mobject.svg.tex_mobject import Tex
-from ..mobject.types.vectorized_mobject import VGroup
-from ..mobject.types.vectorized_mobject import VectorizedPoint
+from ..mobject.geometry import Line, Rectangle, RegularPolygon
+from ..mobject.number_line import NumberLineOld
+from ..mobject.svg.tex_mobject import MathTex, Tex
+from ..mobject.types.vectorized_mobject import VectorizedPoint, VGroup
 from ..scene.scene import Scene
 from ..utils.bezier import interpolate
-from ..utils.color import color_gradient, GREY, BLUE, GREEN, YELLOW, BLACK, WHITE
-from ..utils.color import invert_color
+from ..utils.color import (
+    BLACK,
+    BLUE,
+    GREEN,
+    GREY,
+    WHITE,
+    YELLOW,
+    color_gradient,
+    invert_color,
+)
 from ..utils.space_ops import angle_of_vector
 
 # TODO, this should probably reimplemented entirely, especially so as to
@@ -75,6 +79,14 @@ from ..utils.space_ops import angle_of_vector
 
 
 class GraphScene(Scene):
+    """A special scene intended for plotting functions.
+
+    .. note::
+
+        This class is in the process of being deprecated. Functionality is
+        currently being ported to :class:`~.Axes`.
+    """
+
     def __init__(
         self,
         x_min=-1,
@@ -181,7 +193,7 @@ class GraphScene(Scene):
             **self.x_axis_config,
         )
 
-        x_axis = NumberLine(**self.x_axis_config)
+        x_axis = NumberLineOld(**self.x_axis_config)
         x_shift = x_axis.number_to_point(
             0 if self.x_min <= 0 <= self.x_max else self.x_min
         )
@@ -224,7 +236,7 @@ class GraphScene(Scene):
             **self.y_axis_config,
         )
 
-        y_axis = NumberLine(**self.y_axis_config)
+        y_axis = NumberLineOld(**self.y_axis_config)
         y_shift = y_axis.number_to_point(
             0 if self.y_min <= 0 <= self.y_max else self.y_min
         )
