@@ -4,13 +4,12 @@ __all__ = ["SampleSpaceScene"]
 
 
 from ..animation.animation import Animation
-from ..animation.transform import MoveToTarget
-from ..animation.transform import Transform
+from ..animation.transform import MoveToTarget, Transform
 from ..animation.update import UpdateFromFunc
 from ..constants import *
-from ..scene.scene import Scene
 from ..mobject.probability import SampleSpace
 from ..mobject.types.vectorized_mobject import VGroup
+from ..scene.scene import Scene
 
 
 class SampleSpaceScene(Scene):
