@@ -22,8 +22,7 @@ import numpy as np
 from scipy import linalg
 
 from ..utils.simple_functions import choose
-from ..utils.space_ops import cross2d
-from ..utils.space_ops import find_intersection
+from ..utils.space_ops import cross2d, find_intersection
 
 CLOSED_THRESHOLD: float = 0.001
 
@@ -109,7 +108,9 @@ def interpolate(start: int, end: int, alpha: float) -> float:
     return (1 - alpha) * start + alpha * end
 
 
-def integer_interpolate(start: float, end: float, alpha: float) -> int:
+def integer_interpolate(
+    start: float, end: float, alpha: float
+) -> typing.Tuple[int, float]:
     """
     Alpha is a float between 0 and 1.  This returns
     an integer between start and end (inclusive) representing
