@@ -2,6 +2,7 @@
 
 __all__ = [
     "merge_dicts_recursively",
+    "update_dict_recursively",
     "DictAsObject",
 ]
 
@@ -19,7 +20,7 @@ def merge_dicts_recursively(*dicts):
 
     When values are dictionaries, it is applied recursively
     """
-    result = dict()
+    result = {}
     all_items = it.chain(*[d.items() for d in dicts])
     for key, value in all_items:
         if key in result and isinstance(result[key], dict) and isinstance(value, dict):
@@ -29,10 +30,15 @@ def merge_dicts_recursively(*dicts):
     return result
 
 
+def update_dict_recursively(current_dict, *others):
+    updated_dict = merge_dicts_recursively(current_dict, *others)
+    current_dict.update(updated_dict)
+
+
 # Occasionally convenient in order to write dict.x instead of more laborious
 # (and less in keeping with all other attr accesses) dict["x"]
 
 
 class DictAsObject(object):
-    def __init__(self, dict):
-        self.__dict__ = dict
+    def __init__(self, dictin):
+        self.__dict__ = dictin
