@@ -28,6 +28,9 @@ def extract_mobject_family_members(
         method = Mobject.family_members_with_points
     else:
         method = Mobject.get_family
+    extracted_mobjects = remove_list_redundancies(
+        list(it.chain(*[method(m) for m in mobjects]))
+    )
     if use_z_index:
-        mobjects = sorted(mobjects, key=lambda m: m.z_index)
-    return remove_list_redundancies(list(it.chain(*[method(m) for m in mobjects])))
+        return sorted(extracted_mobjects, key=lambda m: m.z_index)
+    return extracted_mobjects
