@@ -11,12 +11,11 @@ __all__ = [
 
 import os
 import platform
-import time
 import subprocess as sp
-from manim import config, logger
+import time
 from pathlib import Path
 
-from manim import __version__
+from manim import __version__, config, logger
 
 
 def add_extension_if_not_present(file_name, extension):
@@ -85,9 +84,9 @@ def open_media_file(file_writer):
 
     if config["save_last_frame"]:
         file_paths.append(file_writer.image_file_path)
-    if config["write_to_movie"] and not config["save_as_gif"]:
+    if config["write_to_movie"] and not config["format"] == "gif":
         file_paths.append(file_writer.movie_file_path)
-    if config["save_as_gif"]:
+    if config["format"] == "gif":
         file_paths.append(file_writer.gif_file_path)
 
     for file_path in file_paths:
