@@ -4,10 +4,9 @@ __all__ = ["get_full_raster_image_path", "drag_pixels", "invert_image"]
 
 
 import numpy as np
-
-from .. import config
 from PIL import Image
 
+from .. import config
 from ..utils.file_ops import seek_full_path_from_defaults
 
 
@@ -15,7 +14,7 @@ def get_full_raster_image_path(image_file_name):
     return seek_full_path_from_defaults(
         image_file_name,
         default_dir=config.get_dir("assets_dir"),
-        extensions=[".jpg", ".png", ".gif", ".ico"],
+        extensions=[".jpg", ".jpeg", ".png", ".gif", ".ico"],
     )
 
 
