@@ -32,29 +32,29 @@ __all__ = [
 ]
 
 
+import itertools as it
+import math
 from functools import reduce
 
 import numpy as np
-import math
 from mapbox_earcut import triangulate_float32 as earcut
 
-from ..constants import OUT
-from ..constants import PI
-from ..constants import RIGHT
-from ..constants import TAU
-from ..constants import DOWN
+from .. import config
+from ..constants import DOWN, OUT, PI, RIGHT, TAU
 from ..utils.iterables import adjacent_pairs
 from ..utils.simple_functions import fdiv
-import itertools as it
-from .. import config
 
 
 def get_norm(vect):
-    return sum([x ** 2 for x in vect]) ** 0.5
+    logger.warning(
+        "get_norm has been deprecated and will be removed in a future release."
+        "Use np.linalg.norm instead."
+    )
+    return np.linalg.norm(vect)
 
 
 def norm_squared(v):
-    return v[0] * v[0] + v[1] * v[1] + v[2] * v[2]
+    return np.linalg.dot(v, v)
 
 
 # Quaternions
@@ -62,7 +62,7 @@ def norm_squared(v):
 
 
 def quaternion_mult(*quats):
-    if config["use_opengl_renderer"]:
+    if config.renderer == "opengl":
         if len(quats) == 0:
             return [1, 0, 0, 0]
         result = quats[0]
@@ -93,7 +93,7 @@ def quaternion_mult(*quats):
 
 
 def quaternion_from_angle_axis(angle, axis, axis_normalized=False):
-    if config["use_opengl_renderer"]:
+    if config.renderer == "opengl":
         if not axis_normalized:
             axis = normalize(axis)
         return [math.cos(angle / 2), *(math.sin(angle / 2) * axis)]
@@ -191,14 +191,14 @@ def z_to_vector(vector):
     Returns some matrix in SO(3) which takes the z-axis to the
     (normalized) vector provided as an argument
     """
-    norm = get_norm(vector)
+    norm = np.linalg.norm(vector)
     if norm == 0:
         return np.identity(3)
     v = np.array(vector) / norm
     phi = np.arccos(v[2])
     if any(v[:2]):
         # projection of vector to unit circle
-        axis_proj = v[:2] / get_norm(v[:2])
+        axis_proj = v[:2] / np.linalg.norm(v[:2])
         theta = np.arccos(axis_proj[0])
         if axis_proj[1] < 0:
             theta = -theta
@@ -211,14 +211,18 @@ def z_to_vector(vector):
 
 
 def angle_between(v1, v2):
-    return np.arccos(np.dot(v1 / get_norm(v1), v2 / get_norm(v2)))
+    logger.warning(
+        "angle_between has been deprecated and will be removed in a future release."
+        "Use angle_between_vectors instead."
+    )
+    return np.arccos(np.dot(v1 / np.linalg.norm(v1), v2 / np.linalg.norm(v2)))
 
 
 def angle_of_vector(vector):
     """
     Returns polar coordinate theta when vector is project on xy plane
     """
-    if config["use_opengl_renderer"]:
+    if config.renderer == "opengl":
         return np.angle(complex(*vector[:2]))
     else:
         z = complex(*vector[:2])
@@ -232,7 +236,14 @@ def angle_between_vectors(v1, v2):
     Returns the angle between two 3D vectors.
     This angle will always be btw 0 and pi
     """
-    return np.arccos(fdiv(np.dot(v1, v2), get_norm(v1) * get_norm(v2)))
+    if config["renderer"] == "opengl":
+        diff = (angle_of_vector(v2) - angle_of_vector(v1)) % TAU
+        return min(diff, TAU - diff)
+    else:
+        return 2 * np.arctan2(
+            np.linalg.norm(normalize(v1) - normalize(v2)),
+            np.linalg.norm(normalize(v1) + normalize(v2)),
+        )
 
 
 def project_along_vector(point, vector):
@@ -241,7 +252,7 @@ def project_along_vector(point, vector):
 
 
 def normalize(vect, fall_back=None):
-    norm = get_norm(vect)
+    norm = np.linalg.norm(vect)
     if norm > 0:
         return np.array(vect) / norm
     else:
@@ -260,31 +271,29 @@ def normalize_along_axis(array, axis, fall_back=None):
 
 
 def cross(v1, v2):
-    return np.array(
-        [
-            v1[1] * v2[2] - v1[2] * v2[1],
-            v1[2] * v2[0] - v1[0] * v2[2],
-            v1[0] * v2[1] - v1[1] * v2[0],
-        ]
+    logger.warning(
+        "cross has been deprecated and will be removed in a future release."
+        "Use np.cross instead."
     )
+    return np.cross(v1, v2)
 
 
 def get_unit_normal(v1, v2, tol=1e-6):
-    if config["use_opengl_renderer"]:
+    if config.renderer == "opengl":
         v1 = normalize(v1)
         v2 = normalize(v2)
-        cp = cross(v1, v2)
-        cp_norm = get_norm(cp)
+        cp = np.cross(v1, v2)
+        cp_norm = np.linalg.norm(cp)
         if cp_norm < tol:
             # Vectors align, so find a normal to them in the plane shared with the z-axis
-            new_cp = cross(cross(v1, OUT), v1)
-            new_cp_norm = get_norm(new_cp)
+            new_cp = np.cross(np.cross(v1, OUT), v1)
+            new_cp_norm = np.linalg.norm(new_cp)
             if new_cp_norm < tol:
                 return DOWN
             return new_cp / new_cp_norm
         return cp / cp_norm
     else:
-        return normalize(cross(v1, v2))
+        return normalize(np.cross(v1, v2))
 
 
 ###
