@@ -7,12 +7,11 @@ __all__ = [
 
 from .tex import *
 
-
 # This file makes TexTemplateLibrary and TexFontTemplates available for use in manim Tex and MathTex objects.
 
 
 def _new_ams_template():
-    """ Returns a simple Tex Template with only basic AMS packages """
+    """Returns a simple Tex Template with only basic AMS packages"""
     preamble = r"""
 \usepackage[english]{babel}
 \usepackage{amsmath}
@@ -21,6 +20,31 @@ def _new_ams_template():
     return TexTemplate(preamble=preamble)
 
 
+""" Tex Template preamble used by original upstream 3b1b """
+_3b1b_preamble = r"""
+\usepackage[english]{babel}
+\usepackage[utf8]{inputenc}
+\usepackage[T1]{fontenc}
+\usepackage{lmodern}
+\usepackage{amsmath}
+\usepackage{amssymb}
+\usepackage{dsfont}
+\usepackage{setspace}
+\usepackage{tipa}
+\usepackage{relsize}
+\usepackage{textcomp}
+\usepackage{mathrsfs}
+\usepackage{calligra}
+\usepackage{wasysym}
+\usepackage{ragged2e}
+\usepackage{physics}
+\usepackage{xcolor}
+\usepackage{microtype}
+\DisableLigatures{encoding = *, family = * }
+\linespread{1}
+"""
+
+
 # TexTemplateLibrary
 #
 class TexTemplateLibrary(object):
@@ -35,16 +59,16 @@ class TexTemplateLibrary(object):
 
     """
 
-    default = TexTemplate()
+    default = TexTemplate(preamble=_3b1b_preamble)
     """An instance of the default TeX template in manim"""
 
-    threeb1b = TexTemplate()
+    threeb1b = TexTemplate(preamble=_3b1b_preamble)
     """ An instance of the default TeX template used by 3b1b """
 
     ctex = TexTemplate(
         tex_compiler="xelatex",
         output_format=".xdv",
-        preamble=TexTemplate.default_preamble.replace(
+        preamble=_3b1b_preamble.replace(
             r"\DisableLigatures{encoding = *, family = * }", r"\usepackage[UTF8]{ctex}"
         ),
     )
